==> portal-contribuinte-3.162.0.zip: BOOT-INF/classes/br/com/elotech/tributos/repository/integracaocontabil/patrimonial/consulta-inscricoes-no-exercicio.sql <==
select x.entidade,
       x.datamovimentacao,
       x.tributo,
       x.descricaotributo,
       x.classificacaotributo,
       x.situacaolegal,
       x.tipooperacaodeducao,
       x.tipoTributo,
       'INSCRICAO' as tipomovimento,
       x.iddebito,
       x.iddebitoparcelareceita,
       sum(x.valor) as valor
from (
select
      td.entidade,
      case
         when td.datacontabilizacao >= tdp.datalancamento then td.datacontabilizacao
         when td.datainclusao > tdp.datalancamento then td.datainclusao
         else tdp.datalancamento
       end datamovimentacao,
       td.iddebito,
       tr.id as idtributo,
       tdpr.receita as tributo,
       tr.descricao as descricaotributo,
       tr.classificacao as classificacaotributo,
       0 as situacaolegal,
       cast(null as numeric(10)) as tipooperacaodeducao,
       sum(tdpr.valororiginal - coalesce(tdpr.valoratualizacao,0)) as valor,
       tdp.datadividaativa,
       tr.tiporeceita as tipoTributo,
       tdpr.iddebitoparcelareceita
from tribdebito td
left outer join tribdebitoparcela tdp
 on td.entidade         = tdp.entidade
and td.exercicio        = tdp.exercicio
and td.tipocadastro     = tdp.tipocadastro
and td.cadastrogeral    = tdp.cadastrogeral
and td.guiarecolhimento = tdp.guiarecolhimento
and td.subdivida        = tdp.subdivida
left outer join tribdebitoparcelareceita tdpr
 on tdp.entidade         = tdpr.entidade
and tdp.exercicio        = tdpr.exercicio
and tdp.tipocadastro     = tdpr.tipocadastro
and tdp.cadastrogeral    = tdpr.cadastrogeral
and tdp.guiarecolhimento = tdpr.guiarecolhimento
and tdp.subdivida        = tdpr.subdivida
and tdp.parcela          = tdpr.parcela
left outer join tribdebitoreceita tdr
 on tdpr.entidade         = tdr.entidade
and tdpr.exercicio        = tdr.exercicio
and tdpr.tipocadastro     = tdr.tipocadastro
and tdpr.cadastrogeral    = tdr.cadastrogeral
and tdpr.guiarecolhimento = tdr.guiarecolhimento
and tdpr.subdivida        = tdr.subdivida
and tdpr.receita          = tdr.receita
left outer join tribreceita tr
 on tdr.entidade  = tr.entidade
and :exercicio = tr.exercicio
and tdr.receita   = tr.receita
left outer join (select isrec.entidade,
                        isrec.exercicio,
                        isrec.tipocadastro,
                        isrec.cadastrogeral,
                        isrec.guiarecolhimento,
                        isrec.subdivida,
                        isrec.receita,
                        sum(isrec.valorisencao) as valorisencao
                  from tribdebitoreceitaisencao isrec
                  where isrec.valorisencao > 0
                  group by isrec.entidade, isrec.exercicio, isrec.tipocadastro, isrec.cadastrogeral, isrec.guiarecolhimento, isrec.subdivida, isrec.receita
) dados
 on dados.entidade         = tdr.entidade
and dados.exercicio        = tdr.exercicio
and dados.tipocadastro     = tdr.tipocadastro
and dados.cadastrogeral    = tdr.cadastrogeral
and dados.guiarecolhimento = tdr.guiarecolhimento
and dados.subdivida        = tdr.subdivida
and dados.receita          = tdr.receita
where td.constituido = 'S'
  and tdpr.valororiginal - coalesce(tdpr.valoratualizacao,0) > 0
  and not exists (select 1 from tribparcelamentodebito rdeb
                  where rdeb.iddebito = td.iddebito)
  and not exists (select 1 from tribestornoparcelamentodebito tepd
                                    join tribestornoparcelamento tep on tep.idestornoparcelamento = tepd.idestornoparcelamento
                                    join tribparcelamentodebitoorigem tpdo on tpdo.idparcelamento = tep.idparcelamento
                  where tepd.iddebitodestino = td.iddebito
                    and tpdo.iddebito != tepd.iddebitodestino and tep.dataestorno = td.datainclusao)
  and not exists(select 1
                 from triblivroparcelareceita tlpr
                          inner join tribdebitoparcelareceita tdpro
                                     on tlpr.iddebitoparcelareceita = tdpro.iddebitoparcelareceita
                          inner join tribdebitoparcelareceita tdprd on tdprd.entidade = tdpro.entidade
                     and tdprd.exercicio = tdpro.exercicio
                     and tdprd.tipocadastro = tdpro.tipocadastro
                     and tdprd.cadastrogeral = tdpro.cadastrogeral
                     and tdprd.guiarecolhimento = tdpro.guiarecolhimento
                     and tdprd.subdivida = tlpr.novasubdivida
                     and tdprd.receita = tdpro.receita
                 where tdprd.iddebitoparcelareceita = tdpr.iddebitoparcelareceita
                   and tdprd.subdivida != tdpro.subdivida)
  and ((td.datacontabilizacao >= tdp.datalancamento and td.datacontabilizacao in (:datasMovimento)) or
       (((td.datacontabilizacao is null) or (td.datacontabilizacao < tdp.datalancamento)) and
        ((td.datainclusao >= tdp.datalancamento and td.datainclusao in (:datasMovimento))
          or (((td.datainclusao is null) or (td.datainclusao < tdp.datalancamento))  and tdp.datalancamento in (:datasMovimento)))))
  and ((tdp.situacaolegal = 0) or (tdp.situacaolegal in (1, 2) and tdp.datadividaativa >= tdp.datalancamento))
  and not exists(select 1
                 from tribpgtonegociadodebitonovo tpndn
                 where tdpr.entidade = tpndn.entidadedestino and tdpr.exercicio = tpndn.exerciciodestino
                   and tdpr.tipocadastro = tpndn.tipocadastrodestino and tdpr.cadastrogeral = tpndn.cadastrogeraldestino
                   and tdpr.guiarecolhimento = tpndn.guiarecolhimentodestino and tdpr.subdivida = tpndn.subdividadestino
                   and tdpr.parcela = tpndn.parceladestino)
group by
      td.entidade,
      case
         when td.datacontabilizacao >= tdp.datalancamento then td.datacontabilizacao
         when td.datainclusao > tdp.datalancamento then td.datainclusao
         else tdp.datalancamento
       end,
       td.iddebito,
       tr.id,
       tdpr.receita,
       tr.descricao,
       tr.classificacao,
       dados.valorisencao,
       tdp.datadividaativa,
       tdpr.iddebitoparcelareceita,
       tr.tiporeceita
) x
group by x.entidade,
       x.datamovimentacao,
       x.tributo,
       x.descricaotributo,
       x.classificacaotributo,
       x.situacaolegal,
       x.tipooperacaodeducao,
       x.iddebito,
       x.tipoTributo,
       x.iddebitoparcelareceita

==> portal-contribuinte-3.326.0.zip: BOOT-INF/classes/br/com/elotech/tributos/repository/integracaocontabil/patrimonial/consulta-inscricoes-no-exercicio.sql <==
select x.entidade,
       x.datamovimentacao,
       x.tributo,
       x.descricaotributo,
       x.classificacaotributo,
       x.situacaolegal,
       x.tipooperacaodeducao,
       x.tipoTributo,
       'INSCRICAO' as tipomovimento,
       x.iddebito,
       x.idunicopessoa,
       x.iddebitoparcelareceita,
       sum(x.valor) as valor
from (
select
      td.entidade,
      case
         when td.datacontabilizacao >= tdp.datalancamento then td.datacontabilizacao
         when td.datainclusao > tdp.datalancamento then td.datainclusao
         else tdp.datalancamento
       end datamovimentacao,
       td.iddebito,
       p.idunico as idunicopessoa,
       tr.id as idtributo,
       tdpr.receita as tributo,
       tr.descricao as descricaotributo,
       tr.classificacao as classificacaotributo,
       0 as situacaolegal,
       cast(null as numeric(10)) as tipooperacaodeducao,
       sum(tdpr.valororiginal - coalesce(tdpr.valoratualizacao,0)) as valor,
       tdp.datadividaativa,
       tr.tiporeceita as tipoTributo,
       tdpr.iddebitoparcelareceita
from tribdebito td
join tribcadastrogeral tcg
  on td.tipocadastro = tcg.tipocadastro
 and td.cadastrogeral = tcg.cadastrogeral
join pessoa p
  on tcg.pessoa = p.pessoa
left outer join tribdebitoparcela tdp
 on td.entidade         = tdp.entidade
and td.exercicio        = tdp.exercicio
and td.tipocadastro     = tdp.tipocadastro
and td.cadastrogeral    = tdp.cadastrogeral
and td.guiarecolhimento = tdp.guiarecolhimento
and td.subdivida        = tdp.subdivida
left outer join tribdebitoparcelareceita tdpr
 on tdp.entidade         = tdpr.entidade
and tdp.exercicio        = tdpr.exercicio
and tdp.tipocadastro     = tdpr.tipocadastro
and tdp.cadastrogeral    = tdpr.cadastrogeral
and tdp.guiarecolhimento = tdpr.guiarecolhimento
and tdp.subdivida        = tdpr.subdivida
and tdp.parcela          = tdpr.parcela
left outer join tribdebitoreceita tdr
 on tdpr.entidade         = tdr.entidade
and tdpr.exercicio        = tdr.exercicio
and tdpr.tipocadastro     = tdr.tipocadastro
and tdpr.cadastrogeral    = tdr.cadastrogeral
and tdpr.guiarecolhimento = tdr.guiarecolhimento
and tdpr.subdivida        = tdr.subdivida
and tdpr.receita          = tdr.receita
left outer join tribreceita tr
 on tdr.entidade  = tr.entidade
and :exercicio = tr.exercicio
and tdr.receita   = tr.receita
left outer join (select isrec.entidade,
                        isrec.exercicio,
                        isrec.tipocadastro,
                        isrec.cadastrogeral,
                        isrec.guiarecolhimento,
                        isrec.subdivida,
                        isrec.receita,
                        sum(isrec.valorisencao) as valorisencao
                  from tribdebitoreceitaisencao isrec
                  where isrec.valorisencao > 0
                  group by isrec.entidade, isrec.exercicio, isrec.tipocadastro, isrec.cadastrogeral, isrec.guiarecolhimento, isrec.subdivida, isrec.receita
) dados
 on dados.entidade         = tdr.entidade
and dados.exercicio        = tdr.exercicio
and dados.tipocadastro     = tdr.tipocadastro
and dados.cadastrogeral    = tdr.cadastrogeral
and dados.guiarecolhimento = tdr.guiarecolhimento
and dados.subdivida        = tdr.subdivida
and dados.receita          = tdr.receita
where td.constituido = 'S'
  and tdpr.valororiginal - coalesce(tdpr.valoratualizacao,0) > 0
  and not exists (select 1 from tribparcelamentodebito rdeb
                  where rdeb.iddebito = td.iddebito)
  and not exists (select 1 from tribestornoparcelamentodebito tepd
                                    join tribestornoparcelamento tep on tep.idestornoparcelamento = tepd.idestornoparcelamento
                                    join tribparcelamentodebitoorigem tpdo on tpdo.idparcelamento = tep.idparcelamento
                  where tepd.iddebitodestino = td.iddebito
                    and tpdo.iddebito != tepd.iddebitodestino and tep.dataestorno = td.datainclusao)
  and not exists(select 1
                 from triblivroparcelareceita tlpr
                          inner join tribdebitoparcelareceita tdpro
                                     on tlpr.iddebitoparcelareceita = tdpro.iddebitoparcelareceita
                          inner join tribdebitoparcelareceita tdprd on tdprd.entidade = tdpro.entidade
                     and tdprd.exercicio = tdpro.exercicio
                     and tdprd.tipocadastro = tdpro.tipocadastro
                     and tdprd.cadastrogeral = tdpro.cadastrogeral
                     and tdprd.guiarecolhimento = tdpro.guiarecolhimento
                     and tdprd.subdivida = tlpr.novasubdivida
                     and tdprd.receita = tdpro.receita
                 where tdprd.iddebitoparcelareceita = tdpr.iddebitoparcelareceita
                   and tdprd.subdivida != tdpro.subdivida)
  and ((td.datacontabilizacao >= tdp.datalancamento and td.datacontabilizacao in (:datasMovimento)) or
       (((td.datacontabilizacao is null) or (td.datacontabilizacao < tdp.datalancamento)) and
        ((td.datainclusao >= tdp.datalancamento and td.datainclusao in (:datasMovimento))
          or (((td.datainclusao is null) or (td.datainclusao < tdp.datalancamento))  and tdp.datalancamento in (:datasMovimento)))))
  and ((tdp.situacaolegal = 0) or (tdp.situacaolegal in (1, 2) and tdp.datadividaativa >= tdp.datalancamento))
  and not exists(select 1
                 from tribpgtonegociadodebitonovo tpndn
                 where tdpr.entidade = tpndn.entidadedestino and tdpr.exercicio = tpndn.exerciciodestino
                   and tdpr.tipocadastro = tpndn.tipocadastrodestino and tdpr.cadastrogeral = tpndn.cadastrogeraldestino
                   and tdpr.guiarecolhimento = tpndn.guiarecolhimentodestino and tdpr.subdivida = tpndn.subdividadestino
                   and tdpr.parcela = tpndn.parceladestino)
group by
      td.entidade,
      case
         when td.datacontabilizacao >= tdp.datalancamento then td.datacontabilizacao
         when td.datainclusao > tdp.datalancamento then td.datainclusao
         else tdp.datalancamento
       end,
       td.iddebito,
       p.idunico,
       tr.id,
       tdpr.receita,
       tr.descricao,
       tr.classificacao,
       dados.valorisencao,
       tdp.datadividaativa,
       tdpr.iddebitoparcelareceita,
       tr.tiporeceita
) x
group by x.entidade,
       x.datamovimentacao,
       x.tributo,
       x.descricaotributo,
       x.classificacaotributo,
       x.situacaolegal,
       x.tipooperacaodeducao,
       x.iddebito,
       x.idunicopessoa,
       x.tipoTributo,
       x.iddebitoparcelareceita
